/*
 * prefs.c - All the GConf+PonG based prefs related functions.
 *
 * Copyright (C) 2002 Archit Baweja
 *
 * Author(s):
 *	Archit Baweja <bighead@user.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 * USA.
 */


#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <gnome.h>
#include <gconf/gconf.h>
#include <gconf/gconf-client.h>
#include <pong/pong.h>

#include "support.h"
#include "prefs.h"
#include "toolbars.h"


static void
prefs_html_toolbars_refresh_cb (GConfClient *client, guint cnxn_id,
				GConfEntry *entry, gpointer data)
{
	html_toolbars_refresh ();
}


/*
 * Connect callbacks to the GConf notifications.
 */
void
prefs_init_callbacks ()
{
	GConfClient *client;
	GError *err;

	client = gconf_client_get_default ();

	gconf_client_add_dir (client, "/apps/peacock",
			      GCONF_CLIENT_PRELOAD_RECURSIVE, &err);

	/*
	 * If the user changes anything under the
	 * Preferenfes->Editor->HTML Toolbars tab, notify us.
	 */
	gconf_client_notify_add (client, "/apps/peacock/editor/html-toolbars",
				 prefs_html_toolbars_refresh_cb, NULL, NULL,
				 &err);
}	


/*
 * Setup the GConf keys, if peacock is run for the first time.
 */
void
prefs_first_time_setup ()
{
	GConfClient *client;
	GError *err;
	GConfValue *val;
	int i = 0;
	const gchar *keys[] = {
		"/apps/peacock/editor/toolbars/main",
		"/apps/peacock/editor/toolbars/html",
		"/apps/peacock/editor/toolbars/file-browser",
		NULL
	};

	err = NULL;
	val = NULL;
	client = gconf_client_get_default ();

	while (keys) {
		val = gconf_client_get (client, keys[i], &err);
		/*
		 * If error, that means we need to setup defaults.
		 * The special error code check is for a non-existant key.
		 */
		if (1)
			gconf_client_set_bool (client, keys[i], TRUE, &err);

		i++;
	}

	return;
}


/*
 * Initialize GConf and PonG so that Preferences works! 
 * Return Value: 1 on success, 0 on failure.
 */
gint
prefs_init (int argc, char *argv[])
{
	GError *error;

	/*
	 * Initialize GConf.
	 */
	if (!gconf_init (argc, argv, &error)) {
		g_assert (error != NULL);
		g_warning (_("GConf init failed."));
		g_error_free (error);
		error = NULL;
		return 0;
	}

	/*
	 * Initiliaze PonG.
	 */
	if (!pong_init ()) {
		g_warning (_("PonG init failed."));
		return 0;
	}

	pong_add_directory (PACKAGE_PONG_DIR);

/*	prefs_first_time_setup ();*/

	prefs_init_callbacks ();

	return 1;
}


void
prefs_show_dialog ()
{
	static PongXML *prefs = NULL;

	if (!prefs)
		prefs = pong_xml_new ("peacock.pong");

	/*
	 * This NULL check checks for loading errors.
	 */
	if (!prefs) {
		g_warning ("Cannot load preferences dialog");
		return;
	}

	pong_xml_show_dialog (prefs);

	return;
}
